@@ -65,7 +65,7 @@ lzlib_1_11() { [ ${lwarn} = 0 ] &&
 
 # Description of test files for tarlz:
 # test.txt.tar.lz:   1 member (test.txt).
-# t155.tar[.lz]:     directory + file + link + eof, all with 155 char names
+# t155.tar[.lz]:     directory + links + file + eof, all with 155 char names
 # tar_in_tlz1.tar.lz 2 members (test.txt.tar test3.tar) 3 lzip members
 # tar_in_tlz2.tar.lz 2 members (test.txt.tar test3.tar) 5 lzip members
 # test_bad1.tar.lz:  truncated at offset 6000 (of 7495)
@@ -163,10 +163,11 @@ rm -f test.txt || framework_failure
 "${TARLZ}" -xf "${in_tar}" --missing-crc || test_failed $LINENO
 cmp "${in}" test.txt || test_failed $LINENO
 rm -f test.txt || framework_failure
-#
-printf "foo\n" > cfoo || framework_failure
-printf "bar\n" > cbar || framework_failure
-printf "baz\n" > cbaz || framework_failure
+
+# reference files for cmp
+cat "${testdir}"/rfoo > cfoo || framework_failure
+cat "${testdir}"/rbar > cbar || framework_failure
+cat "${testdir}"/rbaz > cbaz || framework_failure
 rm -f foo bar baz || framework_failure
 "${TARLZ}" -xf "${test3_lz}" --missing-crc || test_failed $LINENO
 cmp cfoo foo || test_failed $LINENO
@@ -261,7 +262,7 @@ for i in "${tarint1_lz}" "${tarint2_lz}" ; do
 	cmp out0 out6 || test_failed $LINENO
 	cmp out2 out6 || test_failed $LINENO
 	cmp outv0 outv2 || test_failed $LINENO
-	cmp outv0 outv2 || test_failed $LINENO
+	cmp outv0 outv6 || test_failed $LINENO
 	cmp outv2 outv6 || test_failed $LINENO
 	rm -f out0 out2 out6 outv0 outv2 outv6 || framework_failure
 	"${TARLZ}" -xf "$i" || test_failed $LINENO
@@ -409,14 +410,14 @@ cat cbar > bar || framework_failure
 cat cbaz > baz || framework_failure
 "${TARLZ}" --solid -0 -cf out.tar.lz foo || test_failed $LINENO
 cat out.tar.lz > aout.tar.lz || framework_failure
-for i in --asolid --dsolid --solid -0 ; do
+for i in --asolid --bsolid --dsolid --solid -0 ; do
 	"${TARLZ}" $i -q -rf out.tar.lz bar baz
 	[ $? = 2 ] || test_failed $LINENO $i
 	cmp out.tar.lz aout.tar.lz || test_failed $LINENO $i
 done
 rm -f out.tar.lz aout.tar.lz || framework_failure
-for i in --asolid --dsolid -0 ; do
-	for j in --asolid --dsolid --solid -0 ; do
+for i in --asolid --bsolid --dsolid -0 ; do
+	for j in --asolid --bsolid --dsolid --solid -0 ; do
 		"${TARLZ}" $i -0 -cf out.tar.lz foo ||
 			test_failed $LINENO "$i $j"
 		"${TARLZ}" $j -0 -rf out.tar.lz bar baz ||
